# vBulletin Database Tools.

The vBulletin Database Tools are a series of command line scripts that allow you to quickly make modifications to your database in order to provide performance fixes and update them to UTF8 standards.

> IMPORTANT- These files must be run via the command line, either if you have local access to the server or ssh access. If you are on shared hosting your access may be limited. You may ask your host for ssh access. If they say it is not available ask if they will run the commands for you.

## MyISAMFIX

This tool will convert vBulletin 5 tables to INNODB from MyISAM. This change will generally provide a performance boost to a website. In addition it can help prevent table crashes and improve replication services.

```bash
php myisamfix.phar -dofix
```

## UTF8Table Fix

When using non-English languages, the best practice is to store your data in UTF-8. We recommend using UTF8MB4 with MySQL and MariaDB. This will allow you to use multiple languages properly as well as the popular UTF-8 Emoticon standard.

```bash
php utf8tablefix.phar
```

## SerializeFix

This will fix serialized fields after you have converted them to UTF8MB4. Your vBulletin may not work if you skip this step.

```bash
php serializefix.phar
```

## Update VB5 tables to InnoDB and UTF8

1. Edit vbutil_config.php with a code editor and enter the database credentials. If unsure of the database credentials they can be found in the /core/includes/config.php file.
2. Upload all files (other than readme.md) to your forum root directory
3. Set all the .php and .phar files to chmod 755.
4. In forum Admin CP turn off vBulletin under Settings -> Options -> Turn your Forum On/Off
5. Take a full backup of the forum database
6. With command line change directory to forum root directory
7. Enter command: `php myisamfix.phar -dofix`
    - Wait, this can take some time...
8. Enter command: `php utf8tablefix.phar`
    - Wait again, this can take a long time, especially the node table.
9. Enter command: php serializefix.phar
    - Wait a bit but this is usually fast.
10. Check the /core/includes/config.php file. Find the text:
    ```php
    $config['Mysqli']['charset']
    ```
    If it is set to latin1 such as:
    ```php
    $config['Mysqli']['charset'] = 'latin1';
    ```
    Then change it to:
    ```php
    $config['Mysqli']['charset'] = 'utf8';
    ```
    If it is already set to utf8 or "commented out" then leave the value as it is currently set.
11. Go to your Admin CP and open Languages & Phrases -> Language Manager
12. Edit the settings of each language. Check the HTML Character Set setting and if it isn't UTF-8 change it to UTF-8.
13. Check forum, make sure it is working as expected
14. When you are finsished, delete the myisamfix.phar, utf8tablefix.phar, serializefix.phar and vbutil_config.php files from your server.
15. Turn your vBulletin back on in the AdminCP Settings.

## Database Compare

This is a database repair tool. It will compare two databases and create a list of queries to help synchronize the structures between them. This script should work with any version of vBulletin. To use it, set the Source values in the vbutil_config.php file to match a clean installation of vBulletin. This installation should match the version you want to compare with. The standard database options in the vbutil_config.php file should point to the database that is currently experiencing issues.

```bash
php dbcompare.php indexscript > update.sql
```

You can run the queries by importing them in any tool that allows you to run MySQL Queries

Example:
```bash
mysql -u%user% -Ap %databas% < update.sql
```

Replace %user% and %database% as appropriate.
